@@ -159,6 +159,9 @@ PyType *pyTypeFactory(JSContext *cx, JS::Rooted<JSObject *> *thisObj, JS::Rooted
         memoizePyTypeAndGCThing(s, *rval);   // TODO (Caleb Aikens) consider putting this in the StrType constructor
         return s;
       }
+    case js::ESClass::Array: {
+        return new ListType(cx, obj);
+      }
     default: {
         if (BufferType::isSupportedJsTypes(obj)) { // TypedArray or ArrayBuffer
           // TODO (Tom Tang): ArrayBuffers have cls == js::ESClass::ArrayBuffer
@@ -197,7 +200,8 @@ PyObject *callJSFunc(PyObject *jsCxThisFuncTuple, PyObject *args) {
   JS::RootedValue *jsFunc = (JS::RootedValue *)PyLong_AsVoidPtr(PyTuple_GetItem(jsCxThisFuncTuple, 2));
 
   JS::RootedVector<JS::Value> jsArgsVector(cx);
-  for (size_t i = 0; i < PyTuple_Size(args); i++) {
+  Py_ssize_t tupleSize = PyTuple_Size(args);
+  for (size_t i = 0; i < tupleSize; i++) {
     JS::Value jsValue = jsTypeFactory(cx, PyTuple_GetItem(args, i));
     if (PyErr_Occurred()) { // Check if an exception has already been set in the flow of control
       return NULL; // Fail-fast
